#!/bin/ksh
# Almacena en la variable sdcard el path relativo del dispositivo SD
sdcard=`ls /mnt|grep sdcard.*t`

# Almacena en la variable SDPath el path absoluto del dispositivo SD
SDPath=/mnt/$sdcard

# Monta la tarjeta SD
mount -u $SDPath

# Muestra la pantalla de inicio del proceso
$SDPath/utils/showScreen $SDPath/screens/scriptStart.png

# Borra el archivo .done si lo hubiera
rm -f  $SDPath/.done

# Crea el archivo .started para indicar el comienzo del proceso
echo started > $SDPath/.started

# Monta el filesystem del MMI
mount -uw /mnt/efs-persist

# Hace una copia de seguridad de las BBDD existentes en la SD
cp -v -r /mnt/efs-persist/DataPST.db $SDPath/db/efs-persist/old/
cp -v -r /HBpersistence/DataPST.db $SDPath/db/HBpersistence/old/
cp -v -r /mnt/hmisql/DataPST.db $SDPath/db/hmisql/old/

# Realiza las modificaciones necesarias en la BBDD para acceder al menu ingenieria
$SDPath/utils/sqlite3 /mnt/efs-persist/DataPST.db " delete from tb_intvalues where pst_key=4100 and pst_namespace=4"
$SDPath/utils/sqlite3 /HBpersistence/DataPST.db " delete from tb_intvalues where pst_key=4100 and pst_namespace=4"
$SDPath/utils/sqlite3 /mnt/hmisql/DataPST.db " delete from tb_intvalues where pst_key=4100 and pst_namespace=4"

# Realiza una copia de seguridad de las BBDD modificadas en la SD
cp -v -r /mnt/efs-persist/DataPST.db $SDPath/db/efs-persist/process/
cp -v -r /HBpersistence/DataPST.db $SDPath/db/HBpersistence/process/
cp -v -r /mnt/hmisql/DataPST.db $SDPath/db/hmisql/process/

# Realiza modificaciones adicionales en las BBDD desde valores (4,4100,0) a (4,4100,1)
$SDPath/utils/sqlite3 /mnt/efs-persist/DataPST.db "insert into tb_intvalues (pst_namespace, pst_key, pst_value) values (4,4100,1)"
$SDPath/utils/sqlite3 /HBpersistence/DataPST.db "insert into tb_intvalues (pst_namespace, pst_key, pst_value) values (4,4100,1)"
$SDPath/utils/sqlite3 /mnt/hmisql/DataPST.db "insert into tb_intvalues (pst_namespace, pst_key, pst_value) values (4,4100,1)"

# Realiza una copia de las BBDD definitivas en la SD
cp -v -r /mnt/efs-persist/DataPST.db $SDPath/db/efs-persist/new/
cp -v -r /HBpersistence/DataPST.db $SDPath/db/HBpersistence/new/
cp -v -r /mnt/hmisql/DataPST.db $SDPath/db/hmisql/new/

# Muestra la pantalla de finalizacin del proceso
$SDPath/utils/showScreen $SDPath/screens/scriptDone.png

# Crea el archivo .done para indicar que ha terminado el proceso
echo done > $SDPath/.done

# Borra el archivo .started creado previamente
rm -f  $SDPath/.started
